convert_param_list_to_arg_list

Function convert_param_list_to_arg_list 

pub(crate) fn convert_param_list_to_arg_list(
    list: ParamList,
    make: &SyntaxFactory,
) -> ArgList
Convert a list of function params to a list of arguments that can be passed into a function call.