pub(crate) fn convert_param_list_to_arg_list(
list: ParamList,
make: &SyntaxFactory,
) -> ArgListExpand description
Convert a list of function params to a list of arguments that can be passed into a function call.
pub(crate) fn convert_param_list_to_arg_list(
list: ParamList,
make: &SyntaxFactory,
) -> ArgListConvert a list of function params to a list of arguments that can be passed into a function call.