pub(crate) fn tt_from_syntax(
node: SyntaxNode,
make: &SyntaxFactory,
) -> Vec<NodeOrToken<TokenTree, SyntaxToken>>Expand description
Creates a token tree list from a syntax node, creating the needed delimited sub token trees. Assumes that the input syntax node is a valid syntax tree.